@@ -1175,7 +1175,7 @@ class Line(Object):
 
         self.update();
 
-    def location(self) -> tuple[Location, Location]:
+    def location(self) -> tuple:
         """
         Returns the locations of both the endpoints
         :return: the locations of both the endpoints
